﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Drawing;
using WiimoteLib;

namespace WiimoteWPFTest
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public delegate void UpdateUI(object sender, WiimoteChangedEventArgs args);

        private Wiimote _wm;
        private SolidColorBrush m_myBrush = new SolidColorBrush();

        public MainWindow()
        {
            InitializeComponent();
            _wm = new Wiimote();
            _wm.WiimoteChanged += WiimoteChanged;

            try
            {
                _wm.Connect();
                _wm.SetReportType(InputReport.IRAccel, true);
            }
            catch
            {
                MessageBox.Show("No Wiimote");
                Application.Current.Shutdown();
            }
        }

        private void WiimoteChanged(object sender, WiimoteChangedEventArgs args)
        {
            IRSensor[] sensors = args.WiimoteState.IRState.IRSensors;

            if (sensors[0].Found)
            {
                this.Dispatcher.BeginInvoke(System.Windows.Threading.DispatcherPriority.Normal,
                    new Action(
                        delegate()
                        {
                            int diameter = 0;
                            int posX = 0;

                            if (sensors[1].Found)
                            {
                                int diff = sensors[0].RawPosition.X - sensors[1].RawPosition.X;
                                posX = sensors[0].RawPosition.X - diff / 2;
                                diameter = Math.Abs(diff);
                            }
                            else
                            {
                                diameter = sensors[0].Size + 20;
                                posX = sensors[0].RawPosition.X;
                            }

                            _whiteDot.Width = diameter;
                            _whiteDot.Height = diameter;
                            Canvas.SetLeft(_whiteDot, posX);
                            Canvas.SetTop(_whiteDot, sensors[0].RawPosition.Y);
                        }
                ));
            }           
        }

    }
}
